@@ -39,11 +39,9 @@ from typing import Dict, Optional, Union
 
 from dimp import ContentType, Content, Command, GroupCommand
 
-from ..facebook import Facebook
-from ..messenger import Messenger
-from ..helper import TwinsHelper
-from ..proc_content import ContentProcessor
-from ..proc_content import ContentProcessorFactory
+from ..core.helper import TwinsHelper
+from ..core import Facebook, Messenger
+from ..core import ContentProcessor, ContentProcessorFactory
 
 from .creator import ContentProcessorCreator
 
@@ -88,22 +86,18 @@ class GeneralContentProcessorFactory(TwinsHelper, ContentProcessorFactory):
     def get_processor(self, content: Content) -> Optional[ContentProcessor]:
         msg_type = content.type
         if isinstance(content, Command):
-            name = content.command
+            name = content.cmd
             # command processor
             cpu = self.get_command_processor(msg_type=msg_type, cmd_name=name)
             if cpu is not None:
                 return cpu
-            if isinstance(content, GroupCommand):
+            elif isinstance(content, GroupCommand):
                 # group command processor
                 cpu = self.get_command_processor(msg_type=msg_type, cmd_name='group')
                 if cpu is not None:
                     return cpu
         # content processor
-        cpu = self.get_content_processor(msg_type=msg_type)
-        if cpu is None:
-            # default content processor
-            cpu = self.get_content_processor(msg_type=0)
-        return cpu
+        return self.get_content_processor(msg_type=msg_type)
 
     # Override
     def get_content_processor(self, msg_type: Union[int, ContentType]) -> Optional[ContentProcessor]:
